<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema"
	xmlns:m="http://docs.oasis-open.org/legaldocml/ns/modular/1.0"
	xmlns:akn="http://docs.oasis-open.org/legaldocml/ns/akn/3.0" exclude-result-prefixes="m xsd akn" version="3.0">

	<xsl:output indent="true" />
	<xsl:variable name="modules" select="distinct-values(tokenize(string-join( distinct-values(//@m:if), ' '), ' '))" />

	<xsl:template match="xsd:schema">
		<xsl:variable name="me" select="." />
		<html>
			<head>
				<style>
					ul {
						margin: 0px; 
					}
					p {
						margin-bottom: 0px; 
					}
					section {
						border: solid gray 1px;
						padding: 0px 15px 15px 15px; 
					}
					.error{
						background-color: rgb(255, 240, 240);
					}
				
					.core {
						background-color: rgb(240, 255, 240);					
					}
				</style>
			</head>
			<body>
				<h1>AKN Modules</h1>
				<xsl:for-each select="$modules">
					<xsl:sort select="." />
					<xsl:variable name="module" select="." />
					<section>
						<h2> Module '<xsl:value-of select="$module" />' </h2>
						<xsl:apply-templates select="$me/*[contains(@m:if, $module)]" mode="li">
							<xsl:with-param name="module" tunnel="true" select="$module" />
							<xsl:sort select="local-name(.)" />
						</xsl:apply-templates>
					</section>
				</xsl:for-each>
					<section class="core">
						<h2> Module 'core' </h2>
						<xsl:apply-templates select="$me/*[not(@m:if)]" mode="li">
							<xsl:with-param name="module" tunnel="true">core</xsl:with-param> 
							<xsl:sort select="local-name(.)" />
						</xsl:apply-templates>
					</section>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="*" mode="li" priority="5">
			<p><xsl:apply-templates select="." /></p>
	</xsl:template>

	<xsl:template match="xsd:element[@name]">
		<xsl:variable name="name" select="@name" /> 
		Element <b><xsl:value-of select="$name" /></b>
		<ul>
			<xsl:apply-templates select="//xsd:element[@ref = $name]" />
		</ul>
	</xsl:template>
	<xsl:template match="xsd:element[@ref]">
		<xsl:param name="module" tunnel="true" />
		<xsl:variable name="core" select="$module='core'"/>
		<xsl:variable name="ancestors"
			select="distinct-values(tokenize(string-join(distinct-values(ancestor-or-self::*/@m:if), ' '), ' '))" />
		<li>
			<xsl:if test="not($core or $module = $ancestors)">
				<xsl:attribute name="style">
					<xsl:text>color: white; background-color: rgb(255,120,120);</xsl:text>
				</xsl:attribute> Module <xsl:value-of select="$module" /> not mentioned, </xsl:if> used inside
				<xsl:apply-templates select="ancestor::*[parent::xsd:schema]" mode="label" /></li>
	</xsl:template>
	<xsl:template match="xsd:element[@name]" mode="label"> element <xsl:value-of select="@name" />
	</xsl:template>
	<xsl:template match="xsd:attribute" mode="#all"> attribute <xsl:value-of select="@name" />
	</xsl:template>
	<xsl:template match="xsd:complexType" mode="#all"> complex type <xsl:value-of select="@name" />
	</xsl:template>
	<xsl:template match="xsd:simpleType" mode="#all"> simple type <xsl:value-of select="@name" />
	</xsl:template>
	<xsl:template match="xsd:attributeGroup" mode="#all"> attribute group <xsl:value-of select="@name" />
	</xsl:template>
	<xsl:template match="xsd:group" mode="#all"> group <xsl:value-of select="@name" />
	</xsl:template>
	<xsl:template match="xsd:*" mode="#all"/>
</xsl:stylesheet>
